mailr13213 - in /branches/gui_testing/test_suite/gui_tests: ./ __init__.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 24, 2011 - 11:43:
Author: bugman
Date: Fri Jun 24 11:43:43 2011
New Revision: 13213

URL: http://svn.gna.org/viewcvs/relax?rev=13213&view=rev
Log:
Created a directory for an initial implementation of a GUI testing framework.


Added:
    branches/gui_testing/test_suite/gui_tests/
    branches/gui_testing/test_suite/gui_tests/__init__.py
      - copied, changed from r13209, 
branches/gui_testing/test_suite/system_tests/__init__.py

Copied: branches/gui_testing/test_suite/gui_tests/__init__.py (from r13209, 
branches/gui_testing/test_suite/system_tests/__init__.py)
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/test_suite/gui_tests/__init__.py?p2=branches/gui_testing/test_suite/gui_tests/__init__.py&p1=branches/gui_testing/test_suite/system_tests/__init__.py&r1=13209&r2=13213&rev=13213&view=diff
==============================================================================
--- branches/gui_testing/test_suite/system_tests/__init__.py (original)
+++ branches/gui_testing/test_suite/gui_tests/__init__.py Fri Jun 24 11:43:43 
2011
@@ -21,7 +21,7 @@
 
###############################################################################
 
 # Package docstring.
 """The relax system/functional tests."""
 
 # Python module imports.
 from relax_errors import RelaxError
@@ -31,76 +31,23 @@
 # relax module imports.
 from test_suite.relax_test_runner import RelaxTestRunner
 
-# relax system/functional test module imports.
-from align_tensor import Align_tensor
-from angles import Angles
-from bmrb import Bmrb
-from consistency_tests import Ct
-from dasha import Dasha
-from diffusion_tensor import Diffusion_tensor
-from frame_order import Frame_order
-from generic import Generic
-from jw_mapping import Jw
-from load_spins import Load_spins
-from model_elimination import Modelim
-from model_free import Mf
-from model_selection import Modsel
-from n_state_model import N_state_model
+# relax GUI test module imports.
 from noe import Noe
-from noe_restraints import Noe_restraints
-from palmer import Palmer
-from pdc import Pdc
-from peak_lists import Peak_lists
-from pipes import Pipes
-from relax_data import Relax_data
-from relax_fit import Relax_fit
-from results import Results
-from sequence import Sequence
-from state import State
-from structure import Structure
-from test_suite.relax_test_loader import RelaxTestLoader as TestLoader
-from unit_vectors import Unit_vectors
 
 
-__all__ = ['align_tensor',
-           'angles',
-           'brmb',
-           'consistency_tests',
-           'dasha'
-           'diffusion_tensor',
-           'frame_order',
-           'generic',
-           'jw_mapping',
-           'load_spins',
-           'model_elimination',
-           'model_free',
-           'model_selection',
-           'n_state_model',
-           'noe',
-           'noe_restraints',
-           'palmer',
-           'pdc',
-           'peak_lists'
-           'pipes',
-           'relax_data',
-           'relax_fit',
-           'results',
-           'sequence',
-           'state',
-           'structure',
-           'unit_vectors']
+__all__ = ['noe']
 
 
-class System_test_runner:
-    """Class for executing all of the system/functional tests."""
+class GUI_test_runner:
+    """Class for executing all of the GUI tests."""
 
     def run(self, tests=None):
         """Run the system/functional tests.
 
-        The system test list should be something like 
['N_state_model.test_stereochem_analysis'].  The first part is the imported 
test case class, the second is the specific test.
+        The GUI test list should be something like 
['N_state_model.test_stereochem_analysis'].  The first part is the imported 
test case class, the second is the specific test.
 
 
-        @keyword tests: The list of system tests to preform.
+        @keyword tests: The list of GUI tests to preform.
         @type tests:    list of str
         """
 
@@ -127,33 +74,7 @@
 
         # All tests.
         if not tests:
-            
suite_array.append(TestLoader().loadTestsFromTestCase(Align_tensor))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Bmrb))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Angles))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Ct))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Dasha))
-            
suite_array.append(TestLoader().loadTestsFromTestCase(Diffusion_tensor))
-            
suite_array.append(TestLoader().loadTestsFromTestCase(Frame_order))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Generic))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Jw))
-            
suite_array.append(TestLoader().loadTestsFromTestCase(Load_spins))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Modelim))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Mf))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Modsel))
-            
suite_array.append(TestLoader().loadTestsFromTestCase(N_state_model))
             suite_array.append(TestLoader().loadTestsFromTestCase(Noe))
-            
suite_array.append(TestLoader().loadTestsFromTestCase(Noe_restraints))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Palmer))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Pdc))
-            
suite_array.append(TestLoader().loadTestsFromTestCase(Peak_lists))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Pipes))
-            
suite_array.append(TestLoader().loadTestsFromTestCase(Relax_data))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Relax_fit))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Results))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Sequence))
-            suite_array.append(TestLoader().loadTestsFromTestCase(State))
-            suite_array.append(TestLoader().loadTestsFromTestCase(Structure))
-            
suite_array.append(TestLoader().loadTestsFromTestCase(Unit_vectors))
 
         # Group all tests together.
@@ -21,7 +21,7 @@
 
 # Package docstring.
-"""The relax system/functional tests."""
+"""The relax GUI tests."""
 
 # Python module imports.
@@ -31,76 +31,23 @@
 
     def run(self, tests=None):
-        """Run the system/functional tests.
+        """Run the GUI tests.
 
         full_suite = TestSuite(suite_array)




Related Messages


Powered by MHonArc, Updated Fri Jun 24 12:00:03 2011